# Licensed under the MIT License
# https://github.com/craigahobbs/markdown-up-py/blob/main/LICENSE

"""
markdown-up top-level script environment
"""

from .main import main


if __name__ == '__main__': # pragma: no cover
    main()
